FrameContext

Struct FrameContext 

pub struct FrameContext<'a> { /* private fields */ }
Switch the context of the current session to the given frame reference.

This structure implements Drop, and restores the session context to the current top level window.

Implementations

Source

impl<'a> FrameContext<'a>

pub fn new( session: &'a DriverSession, frameref: JsonValue, ) -> Result<FrameContext<'a>, Error>